package jdk.internal.org.objectweb.asm.commons;

import jdk.internal.org.objectweb.asm.signature.SignatureVisitor;

public class RemappingSignatureAdapter extends SignatureVisitor
{
    private final SignatureVisitor v;
    private final Remapper remapper;
    private String className;
    
    public RemappingSignatureAdapter(SignatureVisitor signatureVisitor, Remapper remapper) {
        this(327680, signatureVisitor, remapper);
    }
    
    protected RemappingSignatureAdapter(int api, SignatureVisitor v, Remapper remapper) {
        super(api);
        this.v = v;
        this.remapper = remapper;
    }
    
    @Override
    public void visitClassType(String className) {
        this.className = className;
        this.v.visitClassType(this.remapper.mapType(className));
    }
    
    @Override
    public void visitInnerClassType(String str) {
        String string = this.remapper.mapType(this.className) + 36;
        this.className = this.className + 36 + str;
        String mapType = this.remapper.mapType(this.className);
        this.v.visitInnerClassType(mapType.substring(mapType.startsWith(string) ? string.length() : (mapType.lastIndexOf(36) + 1)));
    }
    
    @Override
    public void visitFormalTypeParameter(String name) {
        this.v.visitFormalTypeParameter(name);
    }
    
    @Override
    public void visitTypeVariable(String name) {
        this.v.visitTypeVariable(name);
    }
    
    @Override
    public SignatureVisitor visitArrayType() {
        this.v.visitArrayType();
        return this;
    }
    
    @Override
    public void visitBaseType(char descriptor) {
        this.v.visitBaseType(descriptor);
    }
    
    @Override
    public SignatureVisitor visitClassBound() {
        this.v.visitClassBound();
        return this;
    }
    
    @Override
    public SignatureVisitor visitExceptionType() {
        this.v.visitExceptionType();
        return this;
    }
    
    @Override
    public SignatureVisitor visitInterface() {
        this.v.visitInterface();
        return this;
    }
    
    @Override
    public SignatureVisitor visitInterfaceBound() {
        this.v.visitInterfaceBound();
        return this;
    }
    
    @Override
    public SignatureVisitor visitParameterType() {
        this.v.visitParameterType();
        return this;
    }
    
    @Override
    public SignatureVisitor visitReturnType() {
        this.v.visitReturnType();
        return this;
    }
    
    @Override
    public SignatureVisitor visitSuperclass() {
        this.v.visitSuperclass();
        return this;
    }
    
    @Override
    public void visitTypeArgument() {
        this.v.visitTypeArgument();
    }
    
    @Override
    public SignatureVisitor visitTypeArgument(char wildcard) {
        this.v.visitTypeArgument(wildcard);
        return this;
    }
    
    @Override
    public void visitEnd() {
        this.v.visitEnd();
    }
}
